@@ -42,7 +42,7 @@ macro_rules! impl_serde_vec2 {
 
                             fn expecting(
                                 &self,
-                                formatter: &mut std::fmt::Formatter,
+                                formatter: &mut std::fmt::Formatter<'_>,
                             ) -> std::fmt::Result {
                                 formatter.write_str("`x` or `y`")
                             }
@@ -68,7 +68,10 @@ macro_rules! impl_serde_vec2 {
                 impl<'de> Visitor<'de> for TVisitor {
                     type Value = $t;
 
-                    fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+                    fn expecting(
+                        &self,
+                        formatter: &mut std::fmt::Formatter<'_>,
+                    ) -> std::fmt::Result {
                         formatter.write_str(&["struct ", $n].concat())
                     }
 
@@ -158,7 +161,7 @@ macro_rules! impl_serde_vec3 {
 
                             fn expecting(
                                 &self,
-                                formatter: &mut std::fmt::Formatter,
+                                formatter: &mut std::fmt::Formatter<'_>,
                             ) -> std::fmt::Result {
                                 formatter.write_str("`x` or `y` or `z`")
                             }
@@ -185,7 +188,10 @@ macro_rules! impl_serde_vec3 {
                 impl<'de> Visitor<'de> for TVisitor {
                     type Value = $t;
 
-                    fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+                    fn expecting(
+                        &self,
+                        formatter: &mut std::fmt::Formatter<'_>,
+                    ) -> std::fmt::Result {
                         formatter.write_str(&["struct ", $n].concat())
                     }
 
@@ -288,7 +294,7 @@ macro_rules! impl_serde_vec4 {
 
                             fn expecting(
                                 &self,
-                                formatter: &mut std::fmt::Formatter,
+                                formatter: &mut std::fmt::Formatter<'_>,
                             ) -> std::fmt::Result {
                                 formatter.write_str("`x` or `y` or `z` or `w`")
                             }
@@ -316,7 +322,10 @@ macro_rules! impl_serde_vec4 {
                 impl<'de> Visitor<'de> for TVisitor {
                     type Value = $t;
 
-                    fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+                    fn expecting(
+                        &self,
+                        formatter: &mut std::fmt::Formatter<'_>,
+                    ) -> std::fmt::Result {
                         formatter.write_str(&["struct ", $n].concat())
                     }
 
@@ -633,15 +642,15 @@ macro_rules! impl_serde_mat2 {
             where
                 T: Serializer,
             {
-                use serde::ser::SerializeSeq;
+                use serde::ser::SerializeTuple;
 
-                let mut seq = serializer.serialize_seq(Some(4))?;
+                let mut tuple = serializer.serialize_tuple(4)?;
 
-                seq.serialize_element(&self.cols[0].x)?;
-                seq.serialize_element(&self.cols[0].y)?;
-                seq.serialize_element(&self.cols[1].x)?;
-                seq.serialize_element(&self.cols[1].y)?;
-                seq.end()
+                tuple.serialize_element(&self.cols[0].x)?;
+                tuple.serialize_element(&self.cols[0].y)?;
+                tuple.serialize_element(&self.cols[1].x)?;
+                tuple.serialize_element(&self.cols[1].y)?;
+                tuple.end()
             }
         }
 
@@ -655,7 +664,10 @@ macro_rules! impl_serde_mat2 {
                 impl<'de> serde::de::Visitor<'de> for Mat2Visitor {
                     type Value = $name;
 
-                    fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+                    fn expecting(
+                        &self,
+                        formatter: &mut std::fmt::Formatter<'_>,
+                    ) -> std::fmt::Result {
                         formatter.write_str($expecting)
                     }
 
@@ -716,20 +728,20 @@ macro_rules! impl_serde_mat3 {
             where
                 T: Serializer,
             {
-                use serde::ser::SerializeSeq;
+                use serde::ser::SerializeTuple;
 
-                let mut seq = serializer.serialize_seq(Some(9))?;
+                let mut tuple = serializer.serialize_tuple(9)?;
 
-                seq.serialize_element(&self.cols[0].x)?;
-                seq.serialize_element(&self.cols[0].y)?;
-                seq.serialize_element(&self.cols[0].z)?;
-                seq.serialize_element(&self.cols[1].x)?;
-                seq.serialize_element(&self.cols[1].y)?;
-                seq.serialize_element(&self.cols[1].z)?;
-                seq.serialize_element(&self.cols[2].x)?;
-                seq.serialize_element(&self.cols[2].y)?;
-                seq.serialize_element(&self.cols[2].z)?;
-                seq.end()
+                tuple.serialize_element(&self.cols[0].x)?;
+                tuple.serialize_element(&self.cols[0].y)?;
+                tuple.serialize_element(&self.cols[0].z)?;
+                tuple.serialize_element(&self.cols[1].x)?;
+                tuple.serialize_element(&self.cols[1].y)?;
+                tuple.serialize_element(&self.cols[1].z)?;
+                tuple.serialize_element(&self.cols[2].x)?;
+                tuple.serialize_element(&self.cols[2].y)?;
+                tuple.serialize_element(&self.cols[2].z)?;
+                tuple.end()
             }
         }
 
@@ -743,7 +755,10 @@ macro_rules! impl_serde_mat3 {
                 impl<'de> serde::de::Visitor<'de> for Mat3Visitor {
                     type Value = $name;
 
-                    fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+                    fn expecting(
+                        &self,
+                        formatter: &mut std::fmt::Formatter<'_>,
+                    ) -> std::fmt::Result {
                         formatter.write_str($expecting)
                     }
 
@@ -826,27 +841,27 @@ macro_rules! impl_serde_mat4 {
             where
                 T: Serializer,
             {
-                use serde::ser::SerializeSeq;
+                use serde::ser::SerializeTuple;
 
-                let mut seq = serializer.serialize_seq(Some(16))?;
+                let mut tuple = serializer.serialize_tuple(16)?;
 
-                seq.serialize_element(&self.cols[0].x)?;
-                seq.serialize_element(&self.cols[0].y)?;
-                seq.serialize_element(&self.cols[0].z)?;
-                seq.serialize_element(&self.cols[0].w)?;
-                seq.serialize_element(&self.cols[1].x)?;
-                seq.serialize_element(&self.cols[1].y)?;
-                seq.serialize_element(&self.cols[1].z)?;
-                seq.serialize_element(&self.cols[1].w)?;
-                seq.serialize_element(&self.cols[2].x)?;
-                seq.serialize_element(&self.cols[2].y)?;
-                seq.serialize_element(&self.cols[2].z)?;
-                seq.serialize_element(&self.cols[2].w)?;
-                seq.serialize_element(&self.cols[3].x)?;
-                seq.serialize_element(&self.cols[3].y)?;
-                seq.serialize_element(&self.cols[3].z)?;
-                seq.serialize_element(&self.cols[3].w)?;
-                seq.end()
+                tuple.serialize_element(&self.cols[0].x)?;
+                tuple.serialize_element(&self.cols[0].y)?;
+                tuple.serialize_element(&self.cols[0].z)?;
+                tuple.serialize_element(&self.cols[0].w)?;
+                tuple.serialize_element(&self.cols[1].x)?;
+                tuple.serialize_element(&self.cols[1].y)?;
+                tuple.serialize_element(&self.cols[1].z)?;
+                tuple.serialize_element(&self.cols[1].w)?;
+                tuple.serialize_element(&self.cols[2].x)?;
+                tuple.serialize_element(&self.cols[2].y)?;
+                tuple.serialize_element(&self.cols[2].z)?;
+                tuple.serialize_element(&self.cols[2].w)?;
+                tuple.serialize_element(&self.cols[3].x)?;
+                tuple.serialize_element(&self.cols[3].y)?;
+                tuple.serialize_element(&self.cols[3].z)?;
+                tuple.serialize_element(&self.cols[3].w)?;
+                tuple.end()
             }
         }
 
@@ -860,7 +875,10 @@ macro_rules! impl_serde_mat4 {
                 impl<'de> serde::de::Visitor<'de> for Mat4Visitor {
                     type Value = $name;
 
-                    fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+                    fn expecting(
+                        &self,
+                        formatter: &mut std::fmt::Formatter<'_>,
+                    ) -> std::fmt::Result {
                         formatter.write_str($expecting)
                     }
 
@@ -968,17 +986,17 @@ macro_rules! impl_serde_mat4 {
 }
 
 // Allowing the $expected macro in case of extending to integer matrices
-impl_serde_mat2!(Mat2, Vec2, f32, "array of 4 floats");
+impl_serde_mat2!(Mat2, Vec2, f32, "tuple of 4 floats");
 #[cfg(feature = "f64")]
-impl_serde_mat2!(DMat2, DVec2, f64, "array of 4 floats");
+impl_serde_mat2!(DMat2, DVec2, f64, "tuple of 4 floats");
 
-impl_serde_mat3!(Mat3, Vec3, f32, "array of 9 floats");
+impl_serde_mat3!(Mat3, Vec3, f32, "tuple of 9 floats");
 #[cfg(feature = "f64")]
-impl_serde_mat3!(DMat3, DVec3, f64, "array of 9 floats");
+impl_serde_mat3!(DMat3, DVec3, f64, "tuple of 9 floats");
 
-impl_serde_mat4!(Mat4, Vec4, f32, "array of 16 floats");
+impl_serde_mat4!(Mat4, Vec4, f32, "tuple of 16 floats");
 #[cfg(feature = "f64")]
-impl_serde_mat4!(DMat4, DVec4, f64, "array of 16 floats");
+impl_serde_mat4!(DMat4, DVec4, f64, "tuple of 16 floats");
 
 #[cfg(test)]
 mod mat_serde_tests {
@@ -1094,7 +1112,10 @@ impl<'de> Deserialize<'de> for Bivec2 {
                 impl<'de> Visitor<'de> for FieldVisitor {
                     type Value = Field;
 
-                    fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+                    fn expecting(
+                        &self,
+                        formatter: &mut std::fmt::Formatter<'_>,
+                    ) -> std::fmt::Result {
                         formatter.write_str("`xy`")
                     }
 
@@ -1118,7 +1139,7 @@ impl<'de> Deserialize<'de> for Bivec2 {
         impl<'de> Visitor<'de> for Bivec2Visitor {
             type Value = Bivec2;
 
-            fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+            fn expecting(&self, formatter: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
                 formatter.write_str("struct Bivec2")
             }
 
@@ -1192,7 +1213,10 @@ impl<'de> Deserialize<'de> for Bivec3 {
                 impl<'de> Visitor<'de> for FieldVisitor {
                     type Value = Field;
 
-                    fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+                    fn expecting(
+                        &self,
+                        formatter: &mut std::fmt::Formatter<'_>,
+                    ) -> std::fmt::Result {
                         formatter.write_str("`xy` or `xz` or `yz`")
                     }
 
@@ -1218,7 +1242,7 @@ impl<'de> Deserialize<'de> for Bivec3 {
         impl<'de> Visitor<'de> for Bivec3Visitor {
             type Value = Bivec3;
 
-            fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+            fn expecting(&self, formatter: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
                 formatter.write_str("struct Bivec3")
             }
 
@@ -1358,7 +1382,10 @@ impl<'de> Deserialize<'de> for Rotor2 {
                 impl<'de> Visitor<'de> for FieldVisitor {
                     type Value = Field;
 
-                    fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+                    fn expecting(
+                        &self,
+                        formatter: &mut std::fmt::Formatter<'_>,
+                    ) -> std::fmt::Result {
                         formatter.write_str("`s` or `bv`")
                     }
 
@@ -1383,7 +1410,7 @@ impl<'de> Deserialize<'de> for Rotor2 {
         impl<'de> Visitor<'de> for Rotor2Visitor {
             type Value = Rotor2;
 
-            fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+            fn expecting(&self, formatter: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
                 formatter.write_str("struct Rotor2")
             }
 
@@ -1466,7 +1493,10 @@ impl<'de> Deserialize<'de> for Rotor3 {
                 impl<'de> Visitor<'de> for FieldVisitor {
                     type Value = Field;
 
-                    fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+                    fn expecting(
+                        &self,
+                        formatter: &mut std::fmt::Formatter<'_>,
+                    ) -> std::fmt::Result {
                         formatter.write_str("`s` or `bv`")
                     }
 
@@ -1491,7 +1521,7 @@ impl<'de> Deserialize<'de> for Rotor3 {
         impl<'de> Visitor<'de> for Rotor3Visitor {
             type Value = Rotor3;
 
-            fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+            fn expecting(&self, formatter: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
                 formatter.write_str("struct Rotor3")
             }
 
@@ -1637,7 +1667,10 @@ impl<'de> Deserialize<'de> for Isometry2 {
                 impl<'de> Visitor<'de> for FieldVisitor {
                     type Value = Field;
 
-                    fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+                    fn expecting(
+                        &self,
+                        formatter: &mut std::fmt::Formatter<'_>,
+                    ) -> std::fmt::Result {
                         formatter.write_str("`translation` or `rotation`")
                     }
 
@@ -1662,7 +1695,7 @@ impl<'de> Deserialize<'de> for Isometry2 {
         impl<'de> Visitor<'de> for Isometry2Visitor {
             type Value = Isometry2;
 
-            fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+            fn expecting(&self, formatter: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
                 formatter.write_str("struct Isometry2")
             }
 
@@ -1747,7 +1780,10 @@ impl<'de> Deserialize<'de> for Isometry3 {
                 impl<'de> Visitor<'de> for FieldVisitor {
                     type Value = Field;
 
-                    fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+                    fn expecting(
+                        &self,
+                        formatter: &mut std::fmt::Formatter<'_>,
+                    ) -> std::fmt::Result {
                         formatter.write_str("`translation` or `rotation`")
                     }
 
@@ -1772,7 +1808,7 @@ impl<'de> Deserialize<'de> for Isometry3 {
         impl<'de> Visitor<'de> for Isometry3Visitor {
             type Value = Isometry3;
 
-            fn expecting(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
+            fn expecting(&self, formatter: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
                 formatter.write_str("struct Isometry3")
             }
 
